import React from 'react';

/**
 * @function Highlighter 
 * @description DOM for returning highlighted string based on query
 * @returns {String}
 */
const MuiAutocompleteHighlighter = ({option, optionKey, query, settings = {}}) => {
    const splitter = '{/*---*/}';
    const data = optionKey ? option[optionKey] : option;
    const queryContent = settings.isCaseSensitive === true ? query : query.toLowerCase();

    /**
     * @function getQueriedString 
     * @description retrieve queried string from original option text
     * 
     * @returns {String}
     */
    const getQueriedString = () => {
        const index = data.toLowerCase().indexOf(queryContent);
        return data.slice(index, index + query.length);
    }

    return data
        .replace(getQueriedString(), `${splitter}${getQueriedString()}${splitter}`)
        .split(splitter)
        .map(part => {
            const searchedPart = settings.isCaseSensitive === true ? part : part.toLowerCase();

            return {
                text: part,
                isHighlighted: searchedPart.toLowerCase() === queryContent
            }
        })
        .map((part, i) => {
            let text = [];
    
            if(part.isHighlighted) {
                text.push(
                    <strong className={settings.highlightedClass ? settings.highlightedClass : ''} key={`highlighter_index_${i}`}>{part.text}</strong>
                );
            } else {
                text.push(
                    <span className={settings.defaultClass ? settings.defaultClass : ''} key={`highlighter_index_${i}`}>{part.text}</span>
                );
            }
    
            return text;
        });
}

export default MuiAutocompleteHighlighter;